@@ -124,6 +124,6 @@ recipe_ibw = {
     "descr": "binarywave",
     "loader": load_igor,
     "suffix": ".ibw",
-    "mode": "force-distance",
+    "modality": "force-distance",
     "maker": "Asylum Research",
 }
