@@ -50,8 +50,10 @@ META_FIELDS = {
         "grid index y": ["Vertical grid position index", "", fint],
         "grid shape x": ["Horizontal grid shape", "px", fint],
         "grid shape y": ["Vertical grid shape", "px", fint],
-        "grid size x": ["Horizontal grid size", "m", float],
-        "grid size y": ["Vertical grid size", "m", float],
+        # The grid size is the actual size when you include the
+        # boundary of the image (i.e. (grid_shape + 1) * pixel_size).
+        "grid size x": ["Horizontal grid image size", "m", float],
+        "grid size y": ["Vertical grid image size", "m", float],
         "position x": ["Horizontal position", "m", float],
         "position y": ["Vertical position", "m", float],
     },
@@ -122,6 +124,7 @@ class MetaData(dict):
             # nan values are ignored
             return
         super(MetaData, self).__setitem__(key, value)
+        self._autocomplete_grid_metadata()
 
     def __getitem__(self, key):
         if key == "curve id":
@@ -138,6 +141,58 @@ class MetaData(dict):
             raise KeyError(msg)
         return super(MetaData, self).__getitem__(key)
 
+    def _autocomplete_grid_metadata(self):
+        """Compute missing grid metadata in-place
+
+        - supplements "grid index x" and "grid index y" if possible
+        """
+        md = self
+        for ax in ["x", "y"]:
+            if (f"grid index {ax}" not in self
+                and f"grid center {ax}" in self
+                and f"grid shape {ax}" in self
+                and f"grid size {ax}" in self
+                    and f"position {ax}" in self):
+                idx = self._convert_position_to_index(
+                    pos_m=md[f"position {ax}"],
+                    size_m=md[f"grid size {ax}"],
+                    center_m=md[f"grid center {ax}"],
+                    size_px=md[f"grid shape {ax}"])
+                super(MetaData, self).__setitem__(f"grid index {ax}", idx)
+
+    @staticmethod
+    def _convert_position_to_index(pos_m, size_m, center_m, size_px):
+        """Convert qmap positions from [m] to array coordinates in [px]
+
+        Parameters
+        ----------
+        pos_m: float
+            positions [m]
+        size_m: float
+            grid size [m]
+        center_m: float
+            grid center position [m]
+        size_px: int
+            grid size [px]
+
+        Returns
+        -------
+        pos_px: int
+            index position of `pos_m`
+        """
+        if size_px != int(size_px):
+            raise ValueError(
+                "`size_px` must be integer, got {}!".format(size_px))
+        size_px = int(size_px)
+        s1 = center_m - size_m / 2
+        s2 = center_m + size_m / 2
+
+        x, dx = np.linspace(s1, s2, size_px, endpoint=False, retstep=True)
+        x += dx / 2
+
+        xpx = np.nanargmin(np.abs(x - pos_m))
+        return xpx
+
     def _get_curve_id(self):
         # already set?
         thisid = super(MetaData, self).get("curve id")
