@@ -8,7 +8,7 @@ import pytest
 import afmformats
 
 
-datadir = pathlib.Path(__file__).resolve().parent / "data"
+data_path = pathlib.Path(__file__).resolve().parent / "data"
 
 
 def generate_tab_file():
@@ -62,6 +62,14 @@ def test_detect_bad():
         afmformats.formats.get_recipe(tf)
 
 
+def test_open_0_13_3():
+    fdat = afmformats.load_data(data_path / "version_0.13.3.tab")[0]
+    assert fdat.metadata["imaging mode"] == "force-distance"
+    assert fdat["force"][2000] == -6.7762282e-10  # cropped compared to h5 file
+    # set the tip position
+    fdat["tip position"] = fdat["height (measured)"]*1.01
+
+
 def test_open_simple():
     tf = generate_tab_file()
     data = afmformats.load_data(tf)[0]
@@ -72,11 +80,11 @@ def test_open_simple():
 
 
 def test_save_open_with_metadata():
-    jpkfile = datadir / "spot3-0192.jpk-force"
-    fdat = afmformats.load_data(jpkfile, mode="force-distance")[0]
+    jpkfile = data_path / "spot3-0192.jpk-force"
+    fdat = afmformats.load_data(jpkfile, modality="force-distance")[0]
     _, path = tempfile.mkstemp(suffix=".tab", prefix="afmformats_test_")
-    fdat.export(path, metadata=True, fmt="tab")
-    fdat2 = afmformats.load_data(path, mode="force-distance")[0]
+    fdat.export_data(path, metadata=True, fmt="tab")
+    fdat2 = afmformats.load_data(path, modality="force-distance")[0]
     # compare metadata
     for key in fdat.metadata:
         if key in ["path", "format"]:
